# Table of Contents

- [validating-plan-lifecycle-phase](<./validating-plan-lifecycle-phase.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Validating the Plan Lifecycle Phase](<./Validating-the-Plan-Lifecycle-Phase.md>)
  - [Overview](<./Validating-the-Plan-Lifecycle-Phase/Overview.md>)
  - [Configuration](<./Validating-the-Plan-Lifecycle-Phase/Configuration.md>)
  - [Script](<./Validating-the-Plan-Lifecycle-Phase/Script.md>)
  - [Was this page helpful?](<./Validating-the-Plan-Lifecycle-Phase/Was-this-page-helpful.md>)
